@@ -166,8 +166,9 @@ def add_parcelation_colours(colours,parcel,triangles,labels=None,mask=None,fille
     #remove transparent rois
     #find vertices that delineate rois
     if filled:
+        colours=np.zeros_like(colours)
         for l,label in enumerate(rois):
-            colours[parcel==label]
+            colours[np.median(parcel[triangles],axis=1)==label]=labels[label]
         return colours
     neighbours=get_neighbours_from_tris(triangles)
     matrix_colored = np.zeros([len(triangles), len(rois)])
